from macro.window import Window

class Keyboard:
    def __init_(self, *, window: Window = None):
        self.window = window
